@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __GCR_UNLOCK_OPTIONS_H__
@@ -27,6 +25,10 @@ G_BEGIN_DECLS
 #define GCR_UNLOCK_OPTION_TIMEOUT   "timeout"
 #define GCR_UNLOCK_OPTION_IDLE      "idle"
 
+#ifdef __G_IR_SCANNER__
+/* Delete this line when https://bugzilla.gnome.org/show_bug.cgi?id=720504 is fixed */;
+#endif
+
 G_END_DECLS
 
 #endif /* __GCR_UNLOCK_OPTIONS_H__ */
