@@ -688,9 +688,6 @@ test_with_anchor_error_async (Test *test, gconstpointer unused)
 int
 main (int argc, char **argv)
 {
-#if !GLIB_CHECK_VERSION(2,35,0)
-	g_type_init ();
-#endif
 	g_test_init (&argc, &argv, NULL);
 	g_set_prgname ("test-certificate-chain");
 
